==> haskell-pipes-4.3.9-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.9
id: pipes-4.3.9-H8GkYDxpB87CcFqkfqnGqi
key: pipes-4.3.9-H8GkYDxpB87CcFqkfqnGqi
license: BSD-3-Clause
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
abi: c5d8c47cf1608ca175300bb321f5cf5d
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
import-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-4.3.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/pipes-4.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/pipes-4.3.9
hs-libraries: HSpipes-4.3.9-H8GkYDxpB87CcFqkfqnGqi
depends:
    base-4.11.1.0 transformers-0.5.5.0
    exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8
    mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt mtl-2.2.2
    void-0.7.2-JAsenjnj1DBHDal2sW0JoW
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             transformers-0.5.5.0=633c3e5ec737c360775b452ce9aa1e0b
             exceptions-0.10.0-IRO0p79DXGKGDsbbDc50a8=e9779fb859fee3584d68df46d12eac41
             mmorph-1.1.2-u5n0PR0ucK5U9RRLpSUlt=c09e48de7c9591fe7d4e2ba81a9fcf9b
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             void-0.7.2-JAsenjnj1DBHDal2sW0JoW=f14401e2229f003d6e8153beb939779e
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pipes-4.3.9-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-pipes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pipes
version: 4.3.9
id: pipes-4.3.9-Az0WOgj8bj5BB3SWe3vcis
key: pipes-4.3.9-Az0WOgj8bj5BB3SWe3vcis
license: BSD-3-Clause
copyright: 2012-2016 Gabriel Gonzalez
maintainer: Gabriel439@gmail.com
author: Gabriel Gonzalez
synopsis: Compositional pipelines
description:
    `pipes` is a clean and powerful stream processing library that lets you build
    and connect reusable streaming components
    .
    Advantages over traditional streaming libraries:
    .
    * /Concise API/: Use simple commands like '\''for'\'', ('\''>->'\''), '\''await'\'', and '\''yield'\''
    .
    * /Blazing fast/: Implementation tuned for speed, including shortcut fusion
    .
    * /Lightweight Dependency/: @pipes@ is small and compiles very rapidly,
    including dependencies
    .
    * /Elegant semantics/: Use practical category theory
    .
    * /ListT/: Correct implementation of '\''ListT'\'' that interconverts with pipes
    .
    * /Bidirectionality/: Implement duplex channels
    .
    * /Extensive Documentation/: Second to none!
    .
    Import "Pipes" to use the library.
    .
    Read "Pipes.Tutorial" for an extensive tutorial.
category: Control, Pipes
abi: 9f765574e41eb0a92465296060121db8
exposed: True
exposed-modules:
    Pipes Pipes.Core Pipes.Internal Pipes.Lift Pipes.Prelude
    Pipes.Tutorial
import-dirs: /usr/lib/ghc-8.6.1/site-local/pipes-4.3.9
library-dirs: /usr/lib/ghc-8.6.1/site-local/pipes-4.3.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/pipes-4.3.9
hs-libraries: HSpipes-4.3.9-Az0WOgj8bj5BB3SWe3vcis
depends:
    base-4.12.0.0 exceptions-0.10.0-4DJq1L1pYJ32FjrP4E9tSI
    mmorph-1.1.2-1XKbJejgVfn63jvndItiSw mtl-2.2.2 transformers-0.5.5.0
    void-0.7.2-1ijpCmwDTXMGDRdU43YY14
haddock-interfaces: /usr/share/doc/haskell-pipes/html/pipes.haddock
haddock-html: /usr/share/doc/haskell-pipes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
